@@ -2,7 +2,7 @@
 # Copyright (c) 2022 Airbyte, Inc., all rights reserved.
 #
 
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from typing import Any, List, Mapping, Optional
 
@@ -12,7 +12,7 @@ from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class Paginator(RequestOptionsProvider, JsonSchemaMixin):
+class Paginator(ABC, RequestOptionsProvider, JsonSchemaMixin):
     """
     Defines the token to use to fetch the next page of records from the API.
 
