@@ -9,7 +9,12 @@ import pytest
 import requests
 from airbyte_cdk.sources.declarative.decoders.json_decoder import JsonDecoder
 from airbyte_cdk.sources.declarative.interpolation.interpolated_boolean import InterpolatedBoolean
-from airbyte_cdk.sources.declarative.requesters.paginators.default_paginator import DefaultPaginator, RequestOption, RequestOptionType
+from airbyte_cdk.sources.declarative.requesters.paginators.default_paginator import (
+    DefaultPaginator,
+    PaginatorTestReadDecorator,
+    RequestOption,
+    RequestOptionType,
+)
 from airbyte_cdk.sources.declarative.requesters.paginators.strategies.cursor_pagination_strategy import CursorPaginationStrategy
 
 
@@ -202,3 +207,25 @@ def test_reset():
     strategy = MagicMock()
     DefaultPaginator(strategy, config, url_base, options={}, page_size_option=page_size_request_option, page_token_option=page_token_request_option).reset()
     assert strategy.reset.called
+
+
+def test_limit_page_fetched():
+    maximum_number_of_pages = 5
+    number_of_next_performed = maximum_number_of_pages - 1
+    paginator = PaginatorTestReadDecorator(
+        DefaultPaginator(
+            page_size_option=MagicMock(),
+            page_token_option=MagicMock(),
+            pagination_strategy=MagicMock(),
+            config=MagicMock(),
+            url_base=MagicMock(),
+            options={},
+        ),
+        maximum_number_of_pages
+    )
+
+    for _ in range(number_of_next_performed):
+        last_token = paginator.next_page_token(MagicMock(), MagicMock())
+        assert last_token
+
+    assert not paginator.next_page_token(MagicMock(), MagicMock())
