@@ -10,15 +10,17 @@ from airbyte_cdk.sources.declarative.requesters.paginators.strategies.page_incre
 
 
 @pytest.mark.parametrize(
-    "test_name, page_size, expected_next_page_token, expected_offset",
+    "test_name, page_size, start_from, expected_next_page_token, expected_offset",
     [
-        ("test_same_page_size", 2, 1, 1),
-        ("test_larger_page_size", 3, None, 0),
+        ("test_same_page_size_start_from_0", 2, 1, 2, 2),
+        ("test_larger_page_size_start_from_0", 3, 1, None, 1),
+        ("test_same_page_size_start_from_1", 2, 0, 1, 1),
+        ("test_larger_page_size_start_from_0", 3, 0, None, 0)
     ],
 )
-def test_page_increment_paginator_strategy(test_name, page_size, expected_next_page_token, expected_offset):
-    paginator_strategy = PageIncrement(page_size, options={})
-    assert paginator_strategy._page == 0
+def test_page_increment_paginator_strategy(test_name, page_size, start_from, expected_next_page_token, expected_offset):
+    paginator_strategy = PageIncrement(page_size, options={}, start_from_page=start_from)
+    assert paginator_strategy._page == start_from
 
     response = requests.Response()
 
@@ -32,4 +34,4 @@ def test_page_increment_paginator_strategy(test_name, page_size, expected_next_p
     assert expected_offset == paginator_strategy._page
 
     paginator_strategy.reset()
-    assert 0 == paginator_strategy._page
+    assert start_from == paginator_strategy._page
