@@ -15,6 +15,7 @@ from airbyte_cdk.sources.declarative.requesters.request_option import RequestOpt
 from airbyte_cdk.sources.declarative.requesters.requester import HttpMethod
 from airbyte_cdk.sources.declarative.retrievers.simple_retriever import (
     SimpleRetriever,
+    SimpleRetrieverTestReadDecorator,
     _prepared_request_to_airbyte_message,
     _response_to_airbyte_message,
 )
@@ -629,3 +630,28 @@ def test_response_to_airbyte_message(test_name, response_body, response_headers,
     actual_airbyte_message = _response_to_airbyte_message(response)
 
     assert expected_airbyte_message == actual_airbyte_message
+
+
+def test_limit_stream_slices():
+    maximum_number_of_slices = 4
+    stream_slicer = MagicMock()
+    stream_slicer.stream_slices.return_value = _generate_slices(maximum_number_of_slices * 2)
+    retriever = SimpleRetrieverTestReadDecorator(
+        name="stream_name",
+        primary_key=primary_key,
+        requester=MagicMock(),
+        paginator=MagicMock(),
+        record_selector=MagicMock(),
+        stream_slicer=stream_slicer,
+        maximum_number_of_slices=maximum_number_of_slices,
+        options={},
+        config={},
+    )
+
+    truncated_slices = list(retriever.stream_slices(sync_mode=SyncMode.incremental, stream_state=None))
+
+    assert truncated_slices == _generate_slices(maximum_number_of_slices)
+
+
+def _generate_slices(number_of_slices):
+    return [{"date": f"2022-01-0{day + 1}"} for day in range(number_of_slices)]
